#!/usr/bin/env node
var got = require("got");
var program = require("commander");
var config = require("../lib/config");

var authToken = require('../lib').getAuthToken();
var subdomainValue, proxyHostValue, proxyPortValue;
program
	.arguments("<subdomain> <proxyHost> <proxyPort>")
	.action(function(subdomain, proxyHost, proxyPort){
		subdomainValue = subdomain;
		proxyHostValue = proxyHost;
		proxyPortValue = parseInt(proxyPort);
	})
	.parse(process.argv);

if (typeof subdomainValue === 'undefined' || typeof proxyHostValue === 'undefined' || typeof proxyPortValue === 'undefined') {
   console.error('All of subdomain, proxyHost and proxyPort are required');
   process.exit(1);
}

got.post(config.apiBase + "/hosts", {body: {subdomain: subdomainValue, proxyHost: proxyHostValue, proxyPort: proxyPortValue}, headers: {'X-Auth-Token': authToken}, json: true})
.then(function(response){
	console.log("New host created: %s => %s:%s", response.body.subdomain, response.body.proxyHost, response.body.proxyPort);
}).catch(function(error){
	switch(error.response.statusCode){
		case 401:
			console.error("Your authentication token is invalid, please run 'dpc auth'")
			break;
		case 409:
			console.error("This host exists already");
			break;
		case 400:
			console.error("Invalid input:", error.response.body.message);
			break;
		default:
			console.error("Server error", error.response.body);
			break;
	}
});